@@ -311,7 +311,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     ship = os.path.join(basename, "SHIP.tz2")
     out = os.path.join(basename, "OUT.tz2")
 
-    env.Command(ship, targets + sources + [myname], "tar cjf $TARGET $SOURCES")
+    env.Command(ship, sources, "tar cjf $TARGET $SOURCES")
 
     env.Default(targets)
 
